@@ -145,12 +145,14 @@ void raycast()
 	char foo[100];
 	s32 dbuf[SCREEN_WIDTH];
 	int stime, etime;
-
+	int wallraster_time = 0, floorraster_time = 0, raycast_time = 0;
+	int bstime, betime;
+	
 	stime = seconds;
 	/* scan across the screen */
 	for(i=0; i < SCREEN_WIDTH; i++)
 	{
-		s32 angle = FIXED(pa) + (i * (FIXED(60)/SCREEN_WIDTH)) - FIXED(30);
+		s32 angle;
 		int Xa, Ya;
 		int ax, ay;
 		int cur_x, cur_y;
@@ -161,7 +163,10 @@ void raycast()
 		int tex_inc_low, tex_inc_high;
 		int slice_height;
 		int texture_offset; 
+	
+		bstime = seconds;
 		
+		angle = FIXED(pa) + (i * (FIXED(60)/SCREEN_WIDTH)) - FIXED(30);
 		if(angle < FIXED(0)) angle += FIXED(360);
 		if(angle >= FIXED(360)) angle -= FIXED(360);
 		
@@ -192,11 +197,9 @@ void raycast()
 		} else if(angle == FIXED(0) || angle == FIXED(180)) {
 			ax = 1 << 24; Xa = 1 << 24;
 		} else {
-			//ax = FIXED(px) + ((py - ay) << 16) / gba_tan(angle);
 			ax = FIXED(px) + ((py - ay)) * gba_one_over_tan(angle);
 
 			/* calculate X increment between intersections */
-			//Xa = (-Ya << 8) / gba_tan(angle);
 			Xa = ((-Ya) * gba_one_over_tan(angle)) >> 8;
 		}
 		
@@ -300,12 +303,12 @@ void raycast()
 		if(d2 < d1)
 		{
 			wall_hit_x = cur_x; wall_hit_y = cur_y;
-			texture_offset = wall_hit_y % 64;
-			//texture_offset = wall_hit_y - ((wall_hit_y >> 6) << 6);
+			//texture_offset = wall_hit_y % 64;
+			texture_offset = wall_hit_y - ((wall_hit_y >> 6) << 6);
 			distance = d2;
 		} else {
-			texture_offset = wall_hit_x % 64;
-			//texture_offset = wall_hit_x - ((wall_hit_x >> 6) << 6);
+			//texture_offset = wall_hit_x % 64;
+			texture_offset = wall_hit_x - ((wall_hit_x >> 6) << 6);
 			distance = d1;
 		}
 		TRACE("Nearest wall hit at %d/%d\n", wall_hit_x, wall_hit_y);
@@ -317,6 +320,9 @@ void raycast()
 		distance = (distance * gba_cos(abs((FIXED(pa) - angle))));
 
 		TRACE("adjusted distance: %d\n", distance);
+		
+		betime = seconds;
+		raycast_time += (betime - bstime);
 
 		if(distance < FIXED(SLICEHEIGHT_TABLE_SIZE))
 		{
@@ -336,24 +342,34 @@ void raycast()
 		
 		dbuf[i] = FIXED_TO_INT(distance);
 		TRACE("slice height: %d\n", slice_height);
+
 		/* draw here! */
+		bstime = seconds;
 		asm_rasterise_line(i, slice_height, walltextures_Bitmap + 
 			(map[((wall_hit_y/64) * MAP_SIZE_X) + (wall_hit_x/64)] - 1)*64*64,
 			texture_offset, tex_inc_low, tex_inc_high,
 			paltable + ((FIXED_TO_INT(distance)/128) *256));
+		
+		betime = seconds;
+		wallraster_time += (betime - bstime);
 		//sprintf(foo, "%d\n", 	(FIXED_TO_INT(distance)/200) * 32); print(foo);
 	
 		/* floor textures! */
+		bstime = seconds;
 		if(slice_height < SCREEN_HEIGHT)
 		{
 			asm_floor_draw(i, slice_height, walltextures_Bitmap, gba_cos(angle),
 				gba_sin(angle), gba_one_over_cos(abs(FIXED(pa) - angle)), 
 				px, py); 
 		}
+		betime = seconds;
+		floorraster_time += (betime - bstime);
 	}
 	etime = seconds;
 	//sprintf(foo, "raycast time: %d\n", etime - stime); print(foo);
 	
+	//sprintf(foo, "wall: %3d floor: %3d raycast: %3d\n", wallraster_time, floorraster_time, raycast_time); print(foo);
+	
 	stime = seconds;
 	objs_draw(px, py, pa, dbuf);
 	etime = seconds;
@@ -442,7 +458,7 @@ int AgbMain()
 	build_sliceheight_table();
 	
 	REG_TM2CNT = TIMER_FREQ_64 | TIMER_IRQ_ENABLE | TIMER_ENABLE;
-	REG_TM2D = (65536 - 26);
+	REG_TM2D = (65536 - 262);
 	interrupt_init();
 	REG_IE |= INT_TM2; // enable timer 2 for seconds counter
   REG_IME = 1;
