@@ -9,21 +9,13 @@
 #include "keypad.h"
 #include "interrupt.h"
 
+#include "trig.h"
+#include "config.h"
 #include "object.h"
 
-#define SCREEN_WIDTH 120
-#define SCREEN_HEIGHT 160
-
-#define PROJECTION_DISTANCE 208
-
 #define FIXED(x) ((int)((x) * 256))
 #define FIXED_TO_INT(x) ((x)  >> 8)
 
 void print(char *s);
-s32 gba_sin(s32 angle);
-s32 gba_cos(s32 angle);
-s32 gba_tan(s32 angle);
-s32 gba_atan(s32 y, s32 x);
 
 void objs_draw(s32 px, s32 py, s32 angle, s32* dist_buf);
-int pythag(float x, float y);
