@@ -148,12 +148,6 @@ void objs_draw(s32 px, s32 py, s32 angle, s32* dist_buf)
 	if(num_visible_objs > MAX_VISIBLE_OBJS)
 		num_visible_objs = MAX_VISIBLE_OBJS;
 
-	/*for(i=0; i < num_visible_objs; i++)
-	{
-		sprintf(foo, "obj: %d order: %d dist: %d\n", sort_objs_list[i],
-			i, sort_objs[sort_objs_list[i]].dist); print(foo);
-	}*/
-	
 	/* and draw them */
 	stime = seconds;
 	
