@@ -2,5 +2,5 @@
 typedef struct
 {
 	s32 x, y;
-	u8* tex;
+	const u8* tex;
 } texobject;
